@@ -6,5 +6,5 @@ from pathlib import Path
 @dataclass(frozen=True)
 class BootstrapPathsDTO:
     log_dir: Path
-    hash_file: Path
+    crc_file: Path
     report_file: Path
